@@ -28,6 +28,7 @@
 #include <string.h>
 
 #include "totem-menu.h"
+#include "totem.h"
 #include "totem-private.h"
 #include "bacon-video-widget.h"
 #include "egg-recent-view.h"
@@ -527,42 +528,10 @@ totem_action_add_recent (Totem *totem, const char *filename)
 static void
 on_play_disc_activate (GtkMenuItem *menu_item, Totem *totem)
 {
-	MediaType type;
-	GError *error = NULL;
 	char *device_path;
 
 	device_path = g_object_get_data (G_OBJECT (menu_item), "device_path");
-
-	type = totem_cd_detect_type (device_path, &error);
-	switch (type) {
-		case MEDIA_TYPE_ERROR:
-			totem_action_error ("Failed to play Audio/Video Disc",
-					    error ? error->message : "Reason unknown",
-					    totem);
-			return;
-		case MEDIA_TYPE_DATA:
-			/* Maybe set default location to the mountpoint of
-			 * this device?... */
-			{
-				GtkWidget *item;
-
-				item = glade_xml_get_widget
-					(totem->xml, "tmw_open_menu_item");
-				gtk_menu_item_activate (GTK_MENU_ITEM (item));
-			}
-			return;
-		case MEDIA_TYPE_DVD:
-		case MEDIA_TYPE_VCD:
-		case MEDIA_TYPE_CDDA:
-			bacon_video_widget_set_media_device
-				(BACON_VIDEO_WIDGET (totem->bvw), device_path);
-			totem_action_play_media (totem, type);
-			break;
-		default:
-			g_assert_not_reached ();
-	}
-
-	g_free (device_path);
+	totem_action_play_media_device (totem, device_path);
 }
 
 /* A GnomeVFSDrive and GnomeVFSVolume share many similar methods, but do not
@@ -606,8 +575,13 @@ add_device_to_menu (GObject *device, GtkMenu *menu, gint position, Totem *totem)
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), icon);
 
 	g_object_set_data_full (G_OBJECT (menu_item), "device_path",
-			g_strdup (device_path), (GDestroyNotify) g_free);
-	g_free (device_path);
+			device_path, (GDestroyNotify) g_free);
+	if (GNOME_IS_VFS_VOLUME (device)) {
+		g_object_set_data_full (G_OBJECT (menu_item), "activation_uri",
+				gnome_vfs_volume_get_activation_uri (GNOME_VFS_VOLUME (device)),
+				(GDestroyNotify) g_free);
+	}
+
 	g_signal_connect (G_OBJECT (menu_item), "activate",
 			G_CALLBACK (on_play_disc_activate), totem);
 
