@@ -44,6 +44,15 @@
 #define totem_signal_block_by_data(obj, data) (g_signal_handlers_block_matched (obj, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, data))
 #define totem_signal_unblock_by_data(obj, data) (g_signal_handlers_unblock_matched (obj, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, data))
 
+#define totem_set_sensitivity(xml, name, state)		\
+	{							\
+		GtkWidget *widget;				\
+		widget = glade_xml_get_widget (xml, name);	\
+		gtk_widget_set_sensitive (widget, state);	\
+	}
+#define totem_main_set_sensitivity(name, state) totem_set_sensitivity (totem->xml, name, state)
+#define totem_popup_set_sensitivity(name, state) totem_set_sensitivity (totem->xml_popup, name, state)
+
 typedef enum {
 	TOTEM_CONTROLS_VISIBLE,
 	TOTEM_CONTROLS_HIDDEN,
@@ -64,6 +73,8 @@ struct Totem {
 	BaconVideoWidget *bvw;
 	GtkWidget *prefs;
 	GtkWidget *statusbar;
+	GtkWidget *sidebar;
+	gboolean sidebar_shown;
 
 	/* Separate Dialogs */
 	GtkWidget *properties;
@@ -83,7 +94,6 @@ struct Totem {
 
 	/* Volume */
 	GtkWidget *volume;
-	GtkAdjustment *voladj;
 	gboolean vol_lock;
 	gboolean vol_fs_lock;
 	gfloat prev_volume;
@@ -92,6 +102,8 @@ struct Totem {
 	/* Subtitles/Languages menus */
 	GtkWidget *subtitles;
 	GtkWidget *languages;
+	GList *subtitles_list;
+	GList *language_list;
 
 	/* exit fullscreen Popup */
 	GtkWidget *exit_popup;
@@ -117,8 +129,9 @@ struct Totem {
 	EggRecentModel *recent_model;
 	EggRecentViewGtk *recent_view;
 
-	/* Monitor to automatically unmount */
+	/* Monitor for playlist unmounts and drives/volumes monitoring */
 	GnomeVFSVolumeMonitor *monitor;
+	gboolean drives_changed;
 
 	/* session */
 	const char *argv0;
@@ -134,4 +147,6 @@ struct Totem {
 	TotemStates state;
 };
 
+GtkWidget *totem_volume_create (void);
+
 #endif /* __TOTEM_PRIVATE_H__ */
